@@ -11,6 +11,8 @@ except ImportError:
     print "\npygments is not installed yet. Install pygments or run 'pip install -r requirements.txt'.\n"
     sys.exit()
 
+from subprocess import call
+import platform
 import argparse
 #import Image
 import SimpleHTTPServer
@@ -27,6 +29,12 @@ try:
 except ImportError:
     from StringIO import StringIO
 
+if platform.system() == "Windows":
+    print "Windows users install Pykaboo on Cygwin with pip and run it from the Cygwin shell."
+    sys.exit()
+else:
+    pass
+
 class PykabooHTTPRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
     def __init__(self, request, host, server):
         SimpleHTTPServer.SimpleHTTPRequestHandler.__init__(self, request, host, server)
@@ -57,7 +65,7 @@ class PykabooHTTPRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
         css_file = open(path_to_pykaboo_css).read()
         f.write('<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">')
         f.write("<html>\n<head>\n<title>Directory and python file listing for %s</title>\n" % path)
-        f.write('<style type="text/css"> %s</style>\n' %css_file)
+        f.write('<style type="text/css"> %s</style>\n' % css_file)
         f.write('</head>\n')
         f.write("<body>\n<div class=page-container>")
         f.write("\n<div class='title-container'>")
@@ -66,7 +74,6 @@ class PykabooHTTPRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
         #po = open(os.getenv("HOME")+'/Desktop/sc/other/Pykaboo/pykaboo/pyk1.png').read()
         #print po
         #f.write("\n<img width='65' src='pyk1.png' id='symbol'/>\n")
-        #f.write("<img src='http://celebrity.womendiary.net/wp-content/uploads/MaryBonoMack-Scandalous-Pic.jpg'/>")
         f.write("\n</div>")
         f.write("<ul class=shortcut-list>\n")
         f.write("<li class=shortcut-list><a class='sh-c' href=%s>Python standard library modules</a></li>" % path_standard_library)
@@ -81,7 +88,10 @@ class PykabooHTTPRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
         f.write("\n</ul>")  
         f.write("\n<h5>Directory and python file listing for %s</h5>" % path)
         f.write("\n<hr>\n<ul>\n")
-        os.chdir("/")
+        if platform.system() != "windows":
+            os.chdir(root)
+        else:
+            pass
         for name in lis:
             fullname = os.path.join(path, name) 
             displayname = name
@@ -203,11 +213,21 @@ def main():
     else:
         pass
 
-    webbrowser.open("http://localhost:8090")
+ 
 
-    os.chdir("/usr/lib/python2.7")
+    if "cygwin" in platform.system().lower():
+        try: 
+            call(["cygstart", "http://localhost:8090"])
+        except:
+            # Calling it once somehow causes an exception.
+            call(["cygstart", "http://localhost:8090"])
+    else:
+        webbrowser.open("http://localhost:8090")
+
+    os.chdir(path_standard_library)
 
     print "\nType 'pykaboo help' for the list of commands."
+    #print "\nPykaboo is served on 'localhost:8090'"
     print "\nPress <CTRL> + C to stop running pykaboo.\n"
 
     server = BaseHTTPServer.HTTPServer(('', 8090), PykabooHTTPRequestHandler)
@@ -216,6 +236,13 @@ def main():
     except:
         print "\nBye bye!\n"
 
+if platform.system() == "Windows":
+    #windows root: 'C:'
+    root = os.path.splitdrive(sys.executable)[0]+"/"
+else:
+    root = "/"
+    #linux en mac
+
 path_to_pykaboo = os.path.abspath(__file__)
 if path_to_pykaboo.endswith(".pyc"):
     path_to_pykaboo_css = path_to_pykaboo.replace("/__init__.pyc", "/pykaboo_style.css")
